diff --git a/ASLUAV/ASLUAV.h b/ASLUAV/ASLUAV.h
index a6b45ec..04f3e9d 100644
--- a/ASLUAV/ASLUAV.h
+++ b/ASLUAV/ASLUAV.h
@@ -118,7 +118,7 @@ typedef enum MAV_CMD
MAV_CMD_REQUEST_AUTOPILOT_CAPABILITIES=520, /* Request autopilot capabilities |1: Request autopilot version| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_INFORMATION=521, /* WIP: Request camera information (CAMERA_INFORMATION). |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No action 1: Request camera capabilities| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_SETTINGS=522, /* WIP: Request camera settings (CAMERA_SETTINGS) |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No Action 1: Request camera settings| Reserved (all remaining params)| */
- MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB)| */
+ MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB, -1: Lock at current auto value)| */
MAV_CMD_SET_CAMERA_SETTINGS_2=524, /* WIP: Set the camera settings part 2 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Reserved for Flicker mode (0 for Auto)| Reserved for metering mode ID (Average, Center, Spot, etc.)| Reserved for image format ID (Jpeg/Raw/Jpeg+Raw)| Reserved for image quality ID (Compression)| Reserved for color mode ID (Neutral, Vivid, etc.)| Reserved| */
MAV_CMD_REQUEST_STORAGE_INFORMATION=525, /* WIP: Request storage information (STORAGE_INFORMATION) |Storage ID (0 for all, 1 for first, 2 for second, etc.)| 0: No Action 1: Request storage information| Reserved (all remaining params)| */
MAV_CMD_STORAGE_FORMAT=526, /* WIP: Format a storage medium. Once format is complete, a STORAGE_INFORMATION message is sent. |Storage ID (1 for first, 2 for second, etc.)| 0: No action 1: Format storage| Reserved (all remaining params)| */
diff --git a/ardupilotmega/ardupilotmega.h b/ardupilotmega/ardupilotmega.h
index 953a65d..fbba469 100644
--- a/ardupilotmega/ardupilotmega.h
+++ b/ardupilotmega/ardupilotmega.h
@@ -136,7 +136,7 @@ typedef enum MAV_CMD
MAV_CMD_REQUEST_AUTOPILOT_CAPABILITIES=520, /* Request autopilot capabilities |1: Request autopilot version| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_INFORMATION=521, /* WIP: Request camera information (CAMERA_INFORMATION). |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No action 1: Request camera capabilities| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_SETTINGS=522, /* WIP: Request camera settings (CAMERA_SETTINGS) |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No Action 1: Request camera settings| Reserved (all remaining params)| */
- MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB)| */
+ MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB, -1: Lock at current auto value)| */
MAV_CMD_SET_CAMERA_SETTINGS_2=524, /* WIP: Set the camera settings part 2 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Reserved for Flicker mode (0 for Auto)| Reserved for metering mode ID (Average, Center, Spot, etc.)| Reserved for image format ID (Jpeg/Raw/Jpeg+Raw)| Reserved for image quality ID (Compression)| Reserved for color mode ID (Neutral, Vivid, etc.)| Reserved| */
MAV_CMD_REQUEST_STORAGE_INFORMATION=525, /* WIP: Request storage information (STORAGE_INFORMATION) |Storage ID (0 for all, 1 for first, 2 for second, etc.)| 0: No Action 1: Request storage information| Reserved (all remaining params)| */
MAV_CMD_STORAGE_FORMAT=526, /* WIP: Format a storage medium. Once format is complete, a STORAGE_INFORMATION message is sent. |Storage ID (1 for first, 2 for second, etc.)| 0: No action 1: Format storage| Reserved (all remaining params)| */
diff --git a/autoquad/autoquad.h b/autoquad/autoquad.h
index a728def..e99a109 100644
--- a/autoquad/autoquad.h
+++ b/autoquad/autoquad.h
@@ -162,7 +162,7 @@ typedef enum MAV_CMD
MAV_CMD_REQUEST_AUTOPILOT_CAPABILITIES=520, /* Request autopilot capabilities |1: Request autopilot version| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_INFORMATION=521, /* WIP: Request camera information (CAMERA_INFORMATION). |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No action 1: Request camera capabilities| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_SETTINGS=522, /* WIP: Request camera settings (CAMERA_SETTINGS) |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No Action 1: Request camera settings| Reserved (all remaining params)| */
- MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB)| */
+ MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB, -1: Lock at current auto value)| */
MAV_CMD_SET_CAMERA_SETTINGS_2=524, /* WIP: Set the camera settings part 2 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Reserved for Flicker mode (0 for Auto)| Reserved for metering mode ID (Average, Center, Spot, etc.)| Reserved for image format ID (Jpeg/Raw/Jpeg+Raw)| Reserved for image quality ID (Compression)| Reserved for color mode ID (Neutral, Vivid, etc.)| Reserved| */
MAV_CMD_REQUEST_STORAGE_INFORMATION=525, /* WIP: Request storage information (STORAGE_INFORMATION) |Storage ID (0 for all, 1 for first, 2 for second, etc.)| 0: No Action 1: Request storage information| Reserved (all remaining params)| */
MAV_CMD_STORAGE_FORMAT=526, /* WIP: Format a storage medium. Once format is complete, a STORAGE_INFORMATION message is sent. |Storage ID (1 for first, 2 for second, etc.)| 0: No action 1: Format storage| Reserved (all remaining params)| */
diff --git a/common/common.h b/common/common.h
index a602269..dc10099 100644
--- a/common/common.h
+++ b/common/common.h
@@ -464,7 +464,7 @@ typedef enum MAV_CMD
MAV_CMD_REQUEST_AUTOPILOT_CAPABILITIES=520, /* Request autopilot capabilities |1: Request autopilot version| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_INFORMATION=521, /* WIP: Request camera information (CAMERA_INFORMATION). |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No action 1: Request camera capabilities| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_SETTINGS=522, /* WIP: Request camera settings (CAMERA_SETTINGS) |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No Action 1: Request camera settings| Reserved (all remaining params)| */
- MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB)| */
+ MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB, -1: Lock at current auto value)| */
MAV_CMD_SET_CAMERA_SETTINGS_2=524, /* WIP: Set the camera settings part 2 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Reserved for Flicker mode (0 for Auto)| Reserved for metering mode ID (Average, Center, Spot, etc.)| Reserved for image format ID (Jpeg/Raw/Jpeg+Raw)| Reserved for image quality ID (Compression)| Reserved for color mode ID (Neutral, Vivid, etc.)| Reserved| */
MAV_CMD_REQUEST_STORAGE_INFORMATION=525, /* WIP: Request storage information (STORAGE_INFORMATION) |Storage ID (0 for all, 1 for first, 2 for second, etc.)| 0: No Action 1: Request storage information| Reserved (all remaining params)| */
MAV_CMD_STORAGE_FORMAT=526, /* WIP: Format a storage medium. Once format is complete, a STORAGE_INFORMATION message is sent. |Storage ID (1 for first, 2 for second, etc.)| 0: No action 1: Format storage| Reserved (all remaining params)| */
diff --git a/matrixpilot/matrixpilot.h b/matrixpilot/matrixpilot.h
index 3fea234..e65158a 100644
--- a/matrixpilot/matrixpilot.h
+++ b/matrixpilot/matrixpilot.h
@@ -135,7 +135,7 @@ typedef enum MAV_CMD
MAV_CMD_REQUEST_AUTOPILOT_CAPABILITIES=520, /* Request autopilot capabilities |1: Request autopilot version| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_INFORMATION=521, /* WIP: Request camera information (CAMERA_INFORMATION). |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No action 1: Request camera capabilities| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_SETTINGS=522, /* WIP: Request camera settings (CAMERA_SETTINGS) |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No Action 1: Request camera settings| Reserved (all remaining params)| */
- MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB)| */
+ MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB, -1: Lock at current auto value)| */
MAV_CMD_SET_CAMERA_SETTINGS_2=524, /* WIP: Set the camera settings part 2 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Reserved for Flicker mode (0 for Auto)| Reserved for metering mode ID (Average, Center, Spot, etc.)| Reserved for image format ID (Jpeg/Raw/Jpeg+Raw)| Reserved for image quality ID (Compression)| Reserved for color mode ID (Neutral, Vivid, etc.)| Reserved| */
MAV_CMD_REQUEST_STORAGE_INFORMATION=525, /* WIP: Request storage information (STORAGE_INFORMATION) |Storage ID (0 for all, 1 for first, 2 for second, etc.)| 0: No Action 1: Request storage information| Reserved (all remaining params)| */
MAV_CMD_STORAGE_FORMAT=526, /* WIP: Format a storage medium. Once format is complete, a STORAGE_INFORMATION message is sent. |Storage ID (1 for first, 2 for second, etc.)| 0: No action 1: Format storage| Reserved (all remaining params)| */
diff --git a/message_definitions/common.xml b/message_definitions/common.xml
index 199a861..62e2a97 100644
--- a/message_definitions/common.xml
+++ b/message_definitions/common.xml
@@ -1394,7 +1394,7 @@
ISO sensitivity
AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)
EV value (when in auto exposure)
- White balance (color temperature in K) (0: Auto WB)
+ White balance (color temperature in K) (0: Auto WB, -1: Lock at current auto value)
WIP: Set the camera settings part 2 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change.
@@ -4095,7 +4095,7 @@
Shutter speed in seconds
ISO sensitivity
Exposure Value
- Color temperature in degrees Kelvin. (0: Auto WB)
+ Color temperature in degrees Kelvin. (0: Auto WB, -1: Locked at auto value)
Reserved for a camera mode ID. (0: Photo 1: Video)
Audio recording enabled (0: off 1: on)
Reserved for a color mode ID (Neutral, Vivid, etc.)
diff --git a/slugs/slugs.h b/slugs/slugs.h
index cee2053..ef5db1e 100644
--- a/slugs/slugs.h
+++ b/slugs/slugs.h
@@ -118,7 +118,7 @@ typedef enum MAV_CMD
MAV_CMD_REQUEST_AUTOPILOT_CAPABILITIES=520, /* Request autopilot capabilities |1: Request autopilot version| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_INFORMATION=521, /* WIP: Request camera information (CAMERA_INFORMATION). |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No action 1: Request camera capabilities| Reserved (all remaining params)| */
MAV_CMD_REQUEST_CAMERA_SETTINGS=522, /* WIP: Request camera settings (CAMERA_SETTINGS) |Camera ID (0 for all cameras, 1 for first, 2 for second, etc.)| 0: No Action 1: Request camera settings| Reserved (all remaining params)| */
- MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB)| */
+ MAV_CMD_SET_CAMERA_SETTINGS_1=523, /* WIP: Set the camera settings part 1 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Aperture (1/value)| Shutter speed in seconds| ISO sensitivity| AE mode (Auto Exposure) (0: full auto 1: full manual 2: aperture priority 3: shutter priority)| EV value (when in auto exposure)| White balance (color temperature in K) (0: Auto WB, -1: Lock at current auto value)| */
MAV_CMD_SET_CAMERA_SETTINGS_2=524, /* WIP: Set the camera settings part 2 (CAMERA_SETTINGS). Use NAN for reserved values and values you don't want to change. |Camera ID (1 for first, 2 for second, etc.)| Reserved for Flicker mode (0 for Auto)| Reserved for metering mode ID (Average, Center, Spot, etc.)| Reserved for image format ID (Jpeg/Raw/Jpeg+Raw)| Reserved for image quality ID (Compression)| Reserved for color mode ID (Neutral, Vivid, etc.)| Reserved| */
MAV_CMD_REQUEST_STORAGE_INFORMATION=525, /* WIP: Request storage information (STORAGE_INFORMATION) |Storage ID (0 for all, 1 for first, 2 for second, etc.)| 0: No Action 1: Request storage information| Reserved (all remaining params)| */
MAV_CMD_STORAGE_FORMAT=526, /* WIP: Format a storage medium. Once format is complete, a STORAGE_INFORMATION message is sent. |Storage ID (1 for first, 2 for second, etc.)| 0: No action 1: Format storage| Reserved (all remaining params)| */
diff --git a/common/mavlink_msg_camera_settings.h b/common/mavlink_msg_camera_settings.h
index 2a90c43..a1dac91 100644
--- a/common/mavlink_msg_camera_settings.h
+++ b/common/mavlink_msg_camera_settings.h
@@ -10,7 +10,7 @@ typedef struct __mavlink_camera_settings_t {
float shutter_speed; /*< Shutter speed in seconds*/
float iso_sensitivity; /*< ISO sensitivity*/
float ev; /*< Exposure Value*/
- float white_balance; /*< Color temperature in degrees Kelvin. (0: Auto WB)*/
+ float white_balance; /*< Color temperature in degrees Kelvin. (0: Auto WB, -1: Locked at auto value)*/
uint8_t camera_id; /*< Camera ID (1 for first, 2 for second, etc.)*/
uint8_t exposure_mode; /*< 0: full auto 1: full manual 2: aperture priority 3: shutter priority*/
uint8_t mode_id; /*< Reserved for a camera mode ID. (0: Photo 1: Video)*/
@@ -96,7 +96,7 @@ typedef struct __mavlink_camera_settings_t {
* @param shutter_speed Shutter speed in seconds
* @param iso_sensitivity ISO sensitivity
* @param ev Exposure Value
* @param white_balance Color temperature in degrees Kelvin. (0: Auto WB)
* @param mode_id Reserved for a camera mode ID. (0: Photo 1: Video)
* @param audio_recording Audio recording enabled (0: off 1: on)
* @param color_mode_id Reserved for a color mode ID (Neutral, Vivid, etc.)
@@ -172,7 +172,7 @@ static inline uint16_t mavlink_msg_camera_settings_pack(uint8_t system_id, uint8
* @param shutter_speed Shutter speed in seconds
* @param iso_sensitivity ISO sensitivity
* @param ev Exposure Value
* @param white_balance Color temperature in degrees Kelvin. (0: Auto WB)
* @param mode_id Reserved for a camera mode ID. (0: Photo 1: Video)
* @param audio_recording Audio recording enabled (0: off 1: on)
* @param color_mode_id Reserved for a color mode ID (Neutral, Vivid, etc.)
@@ -274,7 +274,7 @@ static inline uint16_t mavlink_msg_camera_settings_encode_chan(uint8_t system_id
* @param shutter_speed Shutter speed in seconds
* @param iso_sensitivity ISO sensitivity
* @param ev Exposure Value
* @param white_balance Color temperature in degrees Kelvin. (0: Auto WB)
* @param mode_id Reserved for a camera mode ID. (0: Photo 1: Video)
* @param audio_recording Audio recording enabled (0: off 1: on)
* @param color_mode_id Reserved for a color mode ID (Neutral, Vivid, etc.)
@@ -482,7 +482,7 @@ static inline float mavlink_msg_camera_settings_get_ev(const mavlink_message_t*
/**
* @brief Get field white_balance from camera_settings message
*
* @return Color temperature in degrees Kelvin. (0: Auto WB)
*/
static inline float mavlink_msg_camera_settings_get_white_balance(const mavlink_message_t* msg)
{
@@ -96,7 +96,7 @@ typedef struct __mavlink_camera_settings_t {
* @param iso_sensitivity ISO sensitivity
* @param ev Exposure Value
- * @param white_balance Color temperature in degrees Kelvin. (0: Auto WB)
+ * @param white_balance Color temperature in degrees Kelvin. (0: Auto WB, -1: Locked at auto value)
* @param mode_id Reserved for a camera mode ID. (0: Photo 1: Video)
* @param audio_recording Audio recording enabled (0: off 1: on)
@@ -172,7 +172,7 @@ static inline uint16_t mavlink_msg_camera_settings_pack(uint8_t system_id, uint8
* @param iso_sensitivity ISO sensitivity
* @param ev Exposure Value
- * @param white_balance Color temperature in degrees Kelvin. (0: Auto WB)
+ * @param white_balance Color temperature in degrees Kelvin. (0: Auto WB, -1: Locked at auto value)
* @param mode_id Reserved for a camera mode ID. (0: Photo 1: Video)
* @param audio_recording Audio recording enabled (0: off 1: on)
@@ -274,7 +274,7 @@ static inline uint16_t mavlink_msg_camera_settings_encode_chan(uint8_t system_id
* @param iso_sensitivity ISO sensitivity
* @param ev Exposure Value
- * @param white_balance Color temperature in degrees Kelvin. (0: Auto WB)
+ * @param white_balance Color temperature in degrees Kelvin. (0: Auto WB, -1: Locked at auto value)
* @param mode_id Reserved for a camera mode ID. (0: Photo 1: Video)
* @param audio_recording Audio recording enabled (0: off 1: on)
@@ -482,7 +482,7 @@ static inline float mavlink_msg_camera_settings_get_ev(const mavlink_message_t*
* @brief Get field white_balance from camera_settings message
*
- * @return Color temperature in degrees Kelvin. (0: Auto WB)
+ * @return Color temperature in degrees Kelvin. (0: Auto WB, -1: Locked at auto value)
*/
static inline float mavlink_msg_camera_settings_get_white_balance(const mavlink_message_t* msg)